@@ -1706,6 +1706,7 @@ open_calendar (ECalBackendSync * backend,
     ScalixContainer *container;
     char *uri;
     const char *prop_default;
+    const char *prop_ssl;
 
     cbs = E_CAL_BACKEND_SCALIX (backend);
     priv = E_CAL_BACKEND_SCALIX_GET_PRIVATE (cbs);
@@ -1719,6 +1720,16 @@ open_calendar (ECalBackendSync * backend,
     source = e_cal_backend_get_source (E_CAL_BACKEND (backend));
     uri = e_source_get_uri (source);
 
+    if ((prop_ssl = e_source_get_property (source, "use_ssl"))) {
+		CamelURL *url;
+
+		url = camel_url_new (uri, NULL);
+		camel_url_set_param (url, "use_ssl", prop_ssl);
+		g_free (uri);
+		uri = camel_url_to_string (url, 0);
+    }
+
+
     GLOG_CAT_INFO (&slcal, "Opening container (%s)",
                    uri != NULL ? uri : "(null)");
     container = scalix_container_open (uri);
